@@ -2,4 +2,4 @@
 # -*- coding: utf-8 -*-
 
 # imports.
-from syst3m.v1 import *
\ No newline at end of file
+from syst3m.classes import *
\ No newline at end of file
