@@ -194,7 +194,7 @@ class WebServer(objects.Thread):
 	def fork(self):
 		print(f"Starting the {self.id}.")
 		serialized = self.dict()
-		serialized["path"] = self.cache.path
+		serialized["path"] = self.__cache__.path
 		for i in ["__cache__","cache",]:
 			del serialized[i]
 		p = subprocess.Popen(["python3", f"{SOURCE_PATH}classes/cache/fork.py", "--serialized", f"'{serialized}'", "--syst3m-webserver-tag", {self.tag}])#, "2>", "/dev/null"])
