@@ -58,18 +58,19 @@ def __check_alias__(
 	if not os.path.exists(base):
 		base = f"/usr/bin/"
 	path = f"{base}/{alias}"
-	if present or not os.path.exists(path):
+	overwrite = "--overwrite" in sys.argv
+	if (("--force" in sys.argv or "--forced" in sys.argv or overwrite) and present) or (present or not os.path.exists(path)):
 		file = f"""#!/usr/bin/env python3\nimport os, sys\npackage="{executable}"\nsys.argv.pop(0)\narguments = sys.argv\ns = ""\nfor i in arguments:\n	if s == "": \n		if " " in i: s = "'"+i+"'"\n		else: s = i\n	else: \n		if " " in i: s += " '"+i+"'"\n		else: s += " "+i\nif os.path.exists("/usr/bin/python3"): os.system("/usr/bin/python3 "+package+" "+s)\nelse:  os.system("python3 "+package+" "+s)"""
-
-		os.system(f"touch {path}")
-		os.system(f"chmod +x {path}")
-		os.system(f"chown {USER}:{GROUP} {path}")
+		sudo = Formats.Boolean("--sudo" in sys.argv).convert(true="sudo ",false="")
+		os.system(f"{sudo}touch {path}")
+		os.system(f"{sudo}chmod +x {path}")
+		os.system(f"{sudo}chown {USER}:{GROUP} {path}")
 		try:
 			Files.File(path=f"{path}", data=file).save()
 		except:
 			print(f"Unable to create alias $ {alias}.")
 			return None
-		os.system(f"chmod +x {path}")
+		os.system(f"{sudo}chmod +x {path}")
 		if '--silent' not in sys.argv:
 			print(f'Successfully created alias: {alias}.')
 			print(f"Check out the docs for more info $: {alias} -h")
@@ -95,10 +96,11 @@ try:
 
 # download.
 except ImportError as e:
+	import os
 	if os.path.exists("/usr/bin/pip3"): 
-		os.system(f"/usr/bin/pip3 install -r {SOURCE_PATH}/requirements/requirements.txt --user {OWNER}")
+		os.system(f"/usr/bin/pip3 install -r {__get_source_path__(__file__, back=3)}/requirements/requirements.txt --user {os.environ.get('USER')}")
 	else:
-		os.system(f"pip3 install -r {SOURCE_PATH}/requirements/requirements.txt")
+		os.system(f"pip3 install -r {__get_source_path__(__file__, back=3)}/requirements/requirements.txt")
 
 	# pip imports.
 	import os, sys, requests, ast, json, pathlib, glob, platform, subprocess, time, random, threading, urllib, flask, logging, multiprocessing
